@@ -3,17 +3,16 @@ import tkinter as tk
 
 def builder(page, cid):
     cache = page.components[cid]
-    master = cache["master"]
-    padding = cache["padding"]
+    container = cache["container"]
     config = cache["config"]
-    frame = tk.Frame(master)
+    frame = tk.Frame(container)
     fill = None
     expand = 0
     if config["fill_row"]:
         fill = tk.X
         expand = 1
+        container.pack(fill=fill, expand=expand)
     frame.pack(side=config["side"], anchor=config["anchor"],
-               padx=padding[0], pady=padding[1],
                fill=fill, expand=expand)
     label = tk.Label(frame, text=config["title"])
     label.pack(anchor="w")
@@ -27,11 +26,15 @@ def builder(page, cid):
         text.config(state="disabled")
     parts = {"frame": frame, "label": label,
              "text": text}
-    return parts, data_getter
+    return parts
 
 
-def data_getter(page, cid):
+def reader(page, cid):
     cache = page.components[cid]
     parts = cache["parts"]
     config = cache["config"]
     return parts["text"].get("1.0", 'end-1c')
+
+
+def updater(page, cid, **config):  # TODO
+    pass
